@@ -20,25 +20,27 @@
 """Curses interface class."""
 from __future__ import unicode_literals
 
-import re
 import sys
 
-from glances.compat import to_ascii, nativestr, b, u, itervalues
+from glances.compat import nativestr, u, itervalues, enable, disable
 from glances.globals import MACOS, WINDOWS
 from glances.logger import logger
 from glances.events import glances_events
-from glances.processes import glances_processes
+from glances.processes import glances_processes, sort_processes_key_list
 from glances.timer import Timer
 
 # Import curses library for "normal" operating system
-if not WINDOWS:
-    try:
-        import curses
-        import curses.panel
-        from curses.textpad import Textbox
-    except ImportError:
-        logger.critical("Curses module not found. Glances cannot start in standalone mode.")
-        sys.exit(1)
+try:
+    import curses
+    import curses.panel
+    from curses.textpad import Textbox
+except ImportError:
+    logger.critical(
+        "Curses module not found. Glances cannot start in standalone mode.")
+    if WINDOWS:
+        logger.critical(
+            "For Windows you can try installing windows-curses with pip install.")
+    sys.exit(1)
 
 
 class _GlancesCurses(object):
@@ -49,48 +51,62 @@ class _GlancesCurses(object):
     """
 
     _hotkeys = {
+        # 'ENTER' > Edit the process filter
         '0': {'switch': 'disable_irix'},
         '1': {'switch': 'percpu'},
         '2': {'switch': 'disable_left_sidebar'},
         '3': {'switch': 'disable_quicklook'},
+        # '4' > Enable or disable quicklook
+        # '5' > Enable or disable top menu
         '6': {'switch': 'meangpu'},
         '/': {'switch': 'process_short_name'},
+        'a': {'sort_key': 'auto'},
         'A': {'switch': 'disable_amps'},
         'b': {'switch': 'byte'},
         'B': {'switch': 'diskio_iops'},
+        'c': {'sort_key': 'cpu_percent'},
         'C': {'switch': 'disable_cloud'},
-        'D': {'switch': 'disable_docker'},
         'd': {'switch': 'disable_diskio'},
+        'D': {'switch': 'disable_docker'},
+        # 'e' > Enable/Disable process extended
+        # 'E' > Erase the process filter
+        # 'f' > Show/hide fs / folder stats
         'F': {'switch': 'fs_free_space'},
         'g': {'switch': 'generate_graph'},
         'G': {'switch': 'disable_gpu'},
         'h': {'switch': 'help_tag'},
+        'i': {'sort_key': 'io_counters'},
         'I': {'switch': 'disable_ip'},
-        'k': {'switch': 'disable_connections'},
+        # 'k' > Kill selected process
+        'K': {'switch': 'disable_connections'},
         'l': {'switch': 'disable_alert'},
+        'm': {'sort_key': 'memory_percent'},
         'M': {'switch': 'reset_minmax_tag'},
         'n': {'switch': 'disable_network'},
         'N': {'switch': 'disable_now'},
+        'p': {'sort_key': 'name'},
         'P': {'switch': 'disable_ports'},
+        # 'q' or ESCAPE > Quit
         'Q': {'switch': 'enable_irq'},
+        'r': {'switch': 'disable_smart'},
         'R': {'switch': 'disable_raid'},
         's': {'switch': 'disable_sensors'},
         'S': {'switch': 'sparkline'},
+        't': {'sort_key': 'cpu_times'},
         'T': {'switch': 'network_sum'},
+        'u': {'sort_key': 'username'},
         'U': {'switch': 'network_cumul'},
+        # 'w' > Delete finished warning logs
         'W': {'switch': 'disable_wifi'},
-        # Processes sort hotkeys
-        'a': {'auto_sort': True, 'sort_key': 'cpu_percent'},
-        'c': {'auto_sort': False, 'sort_key': 'cpu_percent'},
-        'i': {'auto_sort': False, 'sort_key': 'io_counters'},
-        'm': {'auto_sort': False, 'sort_key': 'memory_percent'},
-        'p': {'auto_sort': False, 'sort_key': 'name'},
-        't': {'auto_sort': False, 'sort_key': 'cpu_times'},
-        'u': {'auto_sort': False, 'sort_key': 'username'},
+        # 'x' > Delete finished warning and critical logs
+        # 'z' > Enable or disable processes
+        # "<" (left arrow) navigation through process sort
+        # ">" (right arrow) navigation through process sort
+        # 'UP' > Up in the server list
+        # 'DOWN' > Down in the server list
     }
 
-    _sort_loop = ['cpu_percent', 'memory_percent', 'username',
-                  'cpu_times', 'io_counters', 'name']
+    _sort_loop = sort_processes_key_list
 
     # Define top menu
     _top = ['quicklook', 'cpu', 'percpu', 'gpu', 'mem', 'memswap', 'load']
@@ -98,7 +114,7 @@ class _GlancesCurses(object):
 
     # Define left sidebar
     _left_sidebar = ['network', 'connections', 'wifi', 'ports', 'diskio', 'fs',
-                     'irq', 'folders', 'raid', 'sensors', 'now']
+                     'irq', 'folders', 'raid', 'smart', 'sensors', 'now']
     _left_sidebar_min_width = 23
     _left_sidebar_max_width = 34
 
@@ -143,9 +159,15 @@ class _GlancesCurses(object):
         # Init edit filter tag
         self.edit_filter = False
 
+        # Init kill process tag
+        self.kill_process = False
+
         # Init the process min/max reset
         self.args.reset_minmax_tag = False
 
+        # Init cursor
+        self.args.cursor_position = 0
+
         # Catch key pressed with non blocking mode
         self.term_window.keypad(1)
         self.term_window.nodelay(1)
@@ -187,6 +209,8 @@ class _GlancesCurses(object):
         try:
             if hasattr(curses, 'start_color'):
                 curses.start_color()
+                logger.debug(
+                    'Curses interface compatible with {} colors'.format(curses.COLORS))
             if hasattr(curses, 'use_default_colors'):
                 curses.use_default_colors()
         except Exception as e:
@@ -225,35 +249,35 @@ class _GlancesCurses(object):
             curses.init_pair(8, curses.COLOR_BLUE, -1)
 
             # Colors text styles
-            if curses.COLOR_PAIRS > 8:
-                try:
-                    curses.init_pair(9, curses.COLOR_MAGENTA, -1)
-                except Exception:
-                    if self.is_theme('white'):
-                        curses.init_pair(9, curses.COLOR_BLACK, -1)
-                    else:
-                        curses.init_pair(9, curses.COLOR_WHITE, -1)
-                try:
-                    curses.init_pair(10, curses.COLOR_CYAN, -1)
-                except Exception:
-                    if self.is_theme('white'):
-                        curses.init_pair(10, curses.COLOR_BLACK, -1)
-                    else:
-                        curses.init_pair(10, curses.COLOR_WHITE, -1)
-
-                self.ifWARNING_color2 = curses.color_pair(9) | A_BOLD
-                self.ifCRITICAL_color2 = curses.color_pair(6) | A_BOLD
-                self.filter_color = curses.color_pair(10) | A_BOLD
-
             self.no_color = curses.color_pair(1)
             self.default_color = curses.color_pair(3) | A_BOLD
-            self.nice_color = curses.color_pair(9)
-            self.cpu_time_color = curses.color_pair(9)
+            self.nice_color = curses.color_pair(5)
+            self.cpu_time_color = curses.color_pair(5)
             self.ifCAREFUL_color = curses.color_pair(4) | A_BOLD
             self.ifWARNING_color = curses.color_pair(5) | A_BOLD
             self.ifCRITICAL_color = curses.color_pair(2) | A_BOLD
             self.default_color2 = curses.color_pair(7)
             self.ifCAREFUL_color2 = curses.color_pair(8) | A_BOLD
+            self.ifWARNING_color2 = curses.color_pair(5) | A_BOLD
+            self.ifCRITICAL_color2 = curses.color_pair(6) | A_BOLD
+            self.filter_color = A_BOLD
+            self.selected_color = A_BOLD
+
+            if curses.COLOR_PAIRS > 8:
+                colors_list = [curses.COLOR_MAGENTA, curses.COLOR_CYAN, curses.COLOR_YELLOW]
+                for i in range(0, 3):
+                    try:
+                        curses.init_pair(i + 9, colors_list[i], -1)
+                    except Exception:
+                        if self.is_theme('white'):
+                            curses.init_pair(i + 9, curses.COLOR_BLACK, -1)
+                        else:
+                            curses.init_pair(i + 9, curses.COLOR_WHITE, -1)
+                self.nice_color = curses.color_pair(9)
+                self.cpu_time_color = curses.color_pair(9)
+                self.ifWARNING_color2 = curses.color_pair(9) | A_BOLD
+                self.filter_color = curses.color_pair(10) | A_BOLD
+                self.selected_color = curses.color_pair(11) | A_BOLD
 
         else:
             # The screen is NOT compatible with a colored design
@@ -270,18 +294,20 @@ class _GlancesCurses(object):
             self.ifWARNING_color2 = A_BOLD
             self.ifCRITICAL_color2 = curses.A_REVERSE
             self.filter_color = A_BOLD
+            self.selected_color = A_BOLD
 
         # Define the colors list (hash table) for stats
         self.colors_list = {
             'DEFAULT': self.no_color,
             'UNDERLINE': curses.A_UNDERLINE,
             'BOLD': A_BOLD,
-            'SORT': A_BOLD,
+            'SORT': curses.A_UNDERLINE | A_BOLD,
             'OK': self.default_color2,
-            'MAX': self.default_color2 | curses.A_BOLD,
+            'MAX': self.default_color2 | A_BOLD,
             'FILTER': self.filter_color,
             'TITLE': self.title_color,
             'PROCESS': self.default_color2,
+            'PROCESS_SELECTED': self.default_color2 | curses.A_UNDERLINE,
             'STATUS': self.default_color2,
             'NICE': self.nice_color,
             'CPU_TIME': self.cpu_time_color,
@@ -292,7 +318,8 @@ class _GlancesCurses(object):
             'CAREFUL_LOG': self.ifCAREFUL_color,
             'WARNING_LOG': self.ifWARNING_color,
             'CRITICAL_LOG': self.ifCRITICAL_color,
-            'PASSWORD': curses.A_PROTECT
+            'PASSWORD': curses.A_PROTECT,
+            'SELECTED': self.selected_color
         }
 
     def set_cursor(self, value):
@@ -308,64 +335,62 @@ class _GlancesCurses(object):
             except Exception:
                 pass
 
-    # def get_key(self, window):
-    #     # Catch ESC key AND numlock key (issue #163)
-    #     keycode = [0, 0]
-    #     keycode[0] = window.getch()
-    #     keycode[1] = window.getch()
-    #
-    #     if keycode != [-1, -1]:
-    #         logger.debug("Keypressed (code: %s)" % keycode)
-    #
-    #     if keycode[0] == 27 and keycode[1] != -1:
-    #         # Do not escape on specials keys
-    #         return -1
-    #     else:
-    #         return keycode[0]
-
     def get_key(self, window):
         # @TODO: Check issue #163
         ret = window.getch()
-        logger.debug("Keypressed (code: %s)" % ret)
         return ret
 
     def __catch_key(self, return_to_browser=False):
         # Catch the pressed key
         self.pressedkey = self.get_key(self.term_window)
+        if self.pressedkey == -1:
+            return -1
 
         # Actions (available in the global hotkey dict)...
+        logger.debug("Keypressed (code: {})".format(self.pressedkey))
         for hotkey in self._hotkeys:
             if self.pressedkey == ord(hotkey) and 'switch' in self._hotkeys[hotkey]:
-                setattr(self.args,
-                        self._hotkeys[hotkey]['switch'],
-                        not getattr(self.args,
-                                    self._hotkeys[hotkey]['switch']))
-            if self.pressedkey == ord(hotkey) and 'auto_sort' in self._hotkeys[hotkey]:
-                setattr(glances_processes,
-                        'auto_sort',
-                        self._hotkeys[hotkey]['auto_sort'])
+                # Get the option name
+                # Ex: disable_foo return foo
+                #     enable_foo_bar return foo_bar
+                option = '_'.join(self._hotkeys[hotkey]['switch'].split('_')[1:])
+                if self._hotkeys[hotkey]['switch'].startswith('disable_'):
+                    # disable_ switch
+                    if getattr(self.args,
+                               self._hotkeys[hotkey]['switch']):
+                        enable(self.args, option)
+                    else:
+                        disable(self.args, option)
+                elif self._hotkeys[hotkey]['switch'].startswith('enable_'):
+                    # enable_ switch
+                    if getattr(self.args,
+                               self._hotkeys[hotkey]['switch']):
+                        disable(self.args, option)
+                    else:
+                        enable(self.args, option)
+                else:
+                    # Others switchs options (with no enable_ or disable_)
+                    setattr(self.args,
+                            self._hotkeys[hotkey]['switch'],
+                            not getattr(self.args,
+                                        self._hotkeys[hotkey]['switch']))
             if self.pressedkey == ord(hotkey) and 'sort_key' in self._hotkeys[hotkey]:
-                setattr(glances_processes,
-                        'sort_key',
-                        self._hotkeys[hotkey]['sort_key'])
+                glances_processes.set_sort_key(self._hotkeys[hotkey]['sort_key'],
+                                               self._hotkeys[hotkey]['sort_key'] == 'auto')
 
         # Other actions...
-        if self.pressedkey == ord('\x1b') or self.pressedkey == ord('q'):
-            # 'ESC'|'q' > Quit
-            if return_to_browser:
-                logger.info("Stop Glances client and return to the browser")
-            else:
-                logger.info("Stop Glances (keypressed: {})".format(self.pressedkey))
-        elif self.pressedkey == ord('\n'):
+        if self.pressedkey == ord('\n'):
             # 'ENTER' > Edit the process filter
             self.edit_filter = not self.edit_filter
         elif self.pressedkey == ord('4'):
+            # '4' > Enable or disable quicklook
             self.args.full_quicklook = not self.args.full_quicklook
             if self.args.full_quicklook:
                 self.enable_fullquicklook()
             else:
                 self.disable_fullquicklook()
         elif self.pressedkey == ord('5'):
+            # '5' > Enable or disable top menu
             self.args.disable_top = not self.args.disable_top
             if self.args.disable_top:
                 self.disable_top()
@@ -385,6 +410,9 @@ class _GlancesCurses(object):
             # 'f' > Show/hide fs / folder stats
             self.args.disable_fs = not self.args.disable_fs
             self.args.disable_folders = not self.args.disable_folders
+        elif self.pressedkey == ord('k'):
+            # 'k' > Kill selected process (after confirmation)
+            self.kill_process = not self.kill_process
         elif self.pressedkey == ord('w'):
             # 'w' > Delete finished warning logs
             glances_events.clean()
@@ -400,14 +428,31 @@ class _GlancesCurses(object):
                 glances_processes.enable()
         elif self.pressedkey == curses.KEY_LEFT:
             # "<" (left arrow) navigation through process sort
-            setattr(glances_processes, 'auto_sort', False)
             next_sort = (self.loop_position() - 1) % len(self._sort_loop)
-            glances_processes.sort_key = self._sort_loop[next_sort]
+            glances_processes.set_sort_key(self._sort_loop[next_sort], False)
         elif self.pressedkey == curses.KEY_RIGHT:
             # ">" (right arrow) navigation through process sort
-            setattr(glances_processes, 'auto_sort', False)
             next_sort = (self.loop_position() + 1) % len(self._sort_loop)
-            glances_processes.sort_key = self._sort_loop[next_sort]
+            glances_processes.set_sort_key(self._sort_loop[next_sort], False)
+        elif self.pressedkey == curses.KEY_UP or self.pressedkey == 65:
+            # 'UP' > Up in the server list
+            if self.args.cursor_position > 0:
+                self.args.cursor_position -= 1
+        elif self.pressedkey == curses.KEY_DOWN or self.pressedkey == 66:
+            # 'DOWN' > Down in the server list
+            # if self.args.cursor_position < glances_processes.max_processes - 2:
+            if self.args.cursor_position < glances_processes.processes_count:
+                self.args.cursor_position += 1
+        elif self.pressedkey == ord('\x1b') or self.pressedkey == ord('q'):
+            # 'ESC'|'q' > Quit
+            if return_to_browser:
+                logger.info("Stop Glances client and return to the browser")
+            else:
+                logger.info(
+                    "Stop Glances (keypressed: {})".format(self.pressedkey))
+        elif self.pressedkey == curses.KEY_F5:
+            # "F5" manual refresh requested
+            pass
 
         # Return the key code
         return self.pressedkey
@@ -501,7 +546,7 @@ class _GlancesCurses(object):
             plugin_max_width = None
             if p in self._left_sidebar:
                 plugin_max_width = max(self._left_sidebar_min_width,
-                                       self.screen.getmaxyx()[1] - 105)
+                                       self.term_window.getmaxyx()[1] - 105)
                 plugin_max_width = min(self._left_sidebar_max_width,
                                        plugin_max_width)
 
@@ -537,7 +582,7 @@ class _GlancesCurses(object):
 
         # Adapt number of processes to the available space
         max_processes_displayed = (
-            self.screen.getmaxyx()[0] - 11 -
+            self.term_window.getmaxyx()[0] - 11 -
             (0 if 'docker' not in __stat_display else
                 self.get_stats_display_height(__stat_display["docker"])) -
             (0 if 'processcount' not in __stat_display else
@@ -612,13 +657,38 @@ class _GlancesCurses(object):
                 '- cmdline:.*glances.*\n' +
                 '- username:nicolargo\n' +
                 '- username:^root        ',
-                is_input=True,
+                popup_type='input',
                 input_value=glances_processes.process_filter_input)
             glances_processes.process_filter = new_filter
         elif self.edit_filter and cs_status is not None:
             self.display_popup('Process filter only available in standalone mode')
         self.edit_filter = False
 
+        # Display kill process confirmation popup
+        # Only in standalone mode (cs_status is None)
+        if self.kill_process and cs_status is None:
+            selected_process_raw = stats.get_plugin('processlist').get_raw()[
+                self.args.cursor_position]
+            confirm = self.display_popup(
+                'Kill process: {} (pid: {}) ?\n\nConfirm ([y]es/[n]o): '.format(
+                    selected_process_raw['name'],
+                    selected_process_raw['pid']),
+                popup_type='yesno')
+            if confirm.lower().startswith('y'):
+                try:
+                    ret_kill = glances_processes.kill(selected_process_raw['pid'])
+                except Exception as e:
+                    logger.error('Can not kill process {} ({})'.format(
+                        selected_process_raw['name'], e))
+                else:
+                    logger.info('Kill signal has been sent to process {} (return code: {})'.format(
+                        selected_process_raw['name'], ret_kill))
+
+        elif self.kill_process and cs_status is not None:
+            self.display_popup(
+                'Kill process only available in standalone mode')
+        self.kill_process = False
+
         # Display graph generation popup
         if self.args.generate_graph:
             self.display_popup('Generate graph in {}'.format(self.args.export_graph_path))
@@ -640,10 +710,11 @@ class _GlancesCurses(object):
                 l_uptime += self.get_stats_display_width(stat_display[i])
         self.display_plugin(
             stat_display["system"],
-            display_optional=(self.screen.getmaxyx()[1] >= l_uptime))
+            display_optional=(self.term_window.getmaxyx()[1] >= l_uptime))
         self.space_between_column = 3
-        self.new_column()
-        self.display_plugin(stat_display["ip"])
+        if 'ip' in stat_display:
+            self.new_column()
+            self.display_plugin(stat_display["ip"])
         self.new_column()
         self.display_plugin(
             stat_display["uptime"],
@@ -678,9 +749,9 @@ class _GlancesCurses(object):
         if not self.args.disable_quicklook:
             # Quick look is in the place !
             if self.args.full_quicklook:
-                quicklook_width = self.screen.getmaxyx()[1] - (stats_width + 8 + stats_number * self.space_between_column)
+                quicklook_width = self.term_window.getmaxyx()[1] - (stats_width + 8 + stats_number * self.space_between_column)
             else:
-                quicklook_width = min(self.screen.getmaxyx()[1] - (stats_width + 8 + stats_number * self.space_between_column),
+                quicklook_width = min(self.term_window.getmaxyx()[1] - (stats_width + 8 + stats_number * self.space_between_column),
                                       self._quicklook_max_width - 5)
             try:
                 stat_display["quicklook"] = stats.get_plugin(
@@ -700,14 +771,14 @@ class _GlancesCurses(object):
         for p in self._top:
             plugin_display_optional[p] = True
         if stats_number > 1:
-            self.space_between_column = max(1, int((self.screen.getmaxyx()[1] - stats_width) / (stats_number - 1)))
+            self.space_between_column = max(1, int((self.term_window.getmaxyx()[1] - stats_width) / (stats_number - 1)))
             for p in ['mem', 'cpu']:
                 # No space ? Remove optional stats
                 if self.space_between_column < 3:
                     plugin_display_optional[p] = False
                     plugin_widths[p] = self.get_stats_display_width(stat_display[p], without_option=True) if hasattr(self.args, 'disable_' + p) else 0
                     stats_width = sum(itervalues(plugin_widths)) + 1
-                    self.space_between_column = max(1, int((self.screen.getmaxyx()[1] - stats_width) / (stats_number - 1)))
+                    self.space_between_column = max(1, int((self.term_window.getmaxyx()[1] - stats_width) / (stats_number - 1)))
         else:
             self.space_between_column = 0
 
@@ -718,7 +789,7 @@ class _GlancesCurses(object):
             if p in stat_display:
                 self.display_plugin(stat_display[p],
                                     display_optional=plugin_display_optional[p])
-            if p is not 'load':
+            if p != 'load':
                 # Skip last column
                 self.new_column()
 
@@ -747,7 +818,7 @@ class _GlancesCurses(object):
         docker + processcount + amps + processlist + alert
         """
         # Do not display anything if space is not available...
-        if self.screen.getmaxyx()[1] < self._left_sidebar_min_width:
+        if self.term_window.getmaxyx()[1] < self._left_sidebar_min_width:
             return
 
         # Restore line position
@@ -764,44 +835,51 @@ class _GlancesCurses(object):
                 self.new_line()
                 if p == 'processlist':
                     self.display_plugin(stat_display['processlist'],
-                                        display_optional=(self.screen.getmaxyx()[1] > 102),
+                                        display_optional=(self.term_window.getmaxyx()[1] > 102),
                                         display_additional=(not MACOS),
-                                        max_y=(self.screen.getmaxyx()[0] - self.get_stats_display_height(stat_display['alert']) - 2))
+                                        max_y=(self.term_window.getmaxyx()[0] - self.get_stats_display_height(stat_display['alert']) - 2))
                 else:
                     self.display_plugin(stat_display[p])
 
     def display_popup(self, message,
                       size_x=None, size_y=None,
                       duration=3,
-                      is_input=False,
+                      popup_type='info',
                       input_size=30,
                       input_value=None):
         """
         Display a centered popup.
 
-        If is_input is False:
+        popup_type='info'
+         Just an infotmation popup, no user interaction
          Display a centered popup with the given message during duration seconds
          If size_x and size_y: set the popup size
          else set it automatically
          Return True if the popup could be displayed
 
-        If is_input is True:
+        popup_type='input'
          Display a centered popup with the given message and a input field
          If size_x and size_y: set the popup size
          else set it automatically
          Return the input string or None if the field is empty
+
+        popup_type='yesno'
+         Display a centered popup with the given message
+         If size_x and size_y: set the popup size
+         else set it automatically
+         Return True (yes) or False (no)
         """
         # Center the popup
         sentence_list = message.split('\n')
         if size_x is None:
             size_x = len(max(sentence_list, key=len)) + 4
             # Add space for the input field
-            if is_input:
+            if popup_type == 'input':
                 size_x += input_size
         if size_y is None:
             size_y = len(sentence_list) + 4
-        screen_x = self.screen.getmaxyx()[1]
-        screen_y = self.screen.getmaxyx()[0]
+        screen_x = self.term_window.getmaxyx()[1]
+        screen_y = self.term_window.getmaxyx()[0]
         if size_x > screen_x or size_y > screen_y:
             # No size to display the popup => abord
             return False
@@ -815,10 +893,15 @@ class _GlancesCurses(object):
         popup.border()
 
         # Add the message
-        for y, m in enumerate(message.split('\n')):
+        for y, m in enumerate(sentence_list):
             popup.addnstr(2 + y, 2, m, len(m))
 
-        if is_input and not WINDOWS:
+        if popup_type == 'info':
+            # Display the popup
+            popup.refresh()
+            self.wait(duration * 1000)
+            return True
+        elif popup_type == 'input':
             # Create a subwindow for the text field
             subpop = popup.derwin(1, input_size, 2, 2 + len(m))
             subpop.attron(self.colors_list['FILTER'])
@@ -831,10 +914,10 @@ class _GlancesCurses(object):
             # Create the textbox inside the subwindows
             self.set_cursor(2)
             self.term_window.keypad(1)
-            textbox = GlancesTextbox(subpop, insert_mode=False)
+            textbox = GlancesTextbox(subpop, insert_mode=True)
             textbox.edit()
             self.set_cursor(0)
-            self.term_window.keypad(0)
+            # self.term_window.keypad(0)
             if textbox.gather() != '':
                 logger.debug(
                     "User enters the following string: %s" % textbox.gather())
@@ -842,11 +925,23 @@ class _GlancesCurses(object):
             else:
                 logger.debug("User centers an empty string")
                 return None
-        else:
+        elif popup_type == 'yesno':
+            # # Create a subwindow for the text field
+            subpop = popup.derwin(1, 2, len(sentence_list) + 1, len(m) + 2)
+            subpop.attron(self.colors_list['FILTER'])
+            # Init the field with the current value
+            subpop.addnstr(0, 0, '', 0)
             # Display the popup
             popup.refresh()
-            self.wait(duration * 1000)
-            return True
+            subpop.refresh()
+            # Create the textbox inside the subwindows
+            self.set_cursor(2)
+            self.term_window.keypad(1)
+            textbox = GlancesTextboxYesNo(subpop, insert_mode=False)
+            textbox.edit()
+            self.set_cursor(0)
+            # self.term_window.keypad(0)
+            return textbox.gather()
 
     def display_plugin(self, plugin_stats,
                        display_optional=True,
@@ -868,8 +963,8 @@ class _GlancesCurses(object):
             return 0
 
         # Get the screen size
-        screen_x = self.screen.getmaxyx()[1]
-        screen_y = self.screen.getmaxyx()[0]
+        screen_x = self.term_window.getmaxyx()[1]
+        screen_y = self.term_window.getmaxyx()[0]
 
         # Set the upper/left position of the message
         if plugin_stats['align'] == 'right':
@@ -889,12 +984,16 @@ class _GlancesCurses(object):
         y = display_y
         for m in plugin_stats['msgdict']:
             # New line
-            if m['msg'].startswith('\n'):
-                # Go to the next line
-                y += 1
-                # Return to the first column
-                x = display_x
-                continue
+            try:
+                if m['msg'].startswith('\n'):
+                    # Go to the next line
+                    y += 1
+                    # Return to the first column
+                    x = display_x
+                    continue
+            except:
+                # Avoid exception (see issue #1692)
+                pass
             # Do not display outside the screen
             if x < 0:
                 continue
@@ -988,22 +1087,32 @@ class _GlancesCurses(object):
             duration = 0.1
 
         # Wait duration (in s) time
-        exitkey = False
+        isexitkey = False
         countdown = Timer(duration)
-        # Set the default timeout (in ms) for the getch method
-        self.term_window.timeout(int(duration * 1000))
-        while not countdown.finished() and not exitkey:
+        # Set the default timeout (in ms) between two getch
+        self.term_window.timeout(100)
+        while not countdown.finished() and not isexitkey:
             # Getkey
             pressedkey = self.__catch_key(return_to_browser=return_to_browser)
-            # Is it an exit key ?
-            exitkey = (pressedkey == ord('\x1b') or pressedkey == ord('q'))
-            if not exitkey and pressedkey > -1:
+            isexitkey = (pressedkey == ord('\x1b') or pressedkey == ord('q'))
+
+            if pressedkey == curses.KEY_F5:
+                # Were asked to refresh
+                return isexitkey
+
+            if isexitkey and self.args.help_tag:
+                # Quit from help should return to main screen, not exit #1874
+                self.args.help_tag = not self.args.help_tag
+                isexitkey = False
+                return isexitkey
+
+            if not isexitkey and pressedkey > -1:
                 # Redraw display
                 self.flush(stats, cs_status=cs_status)
                 # Overwrite the timeout with the countdown
-                self.term_window.timeout(int(countdown.get() * 1000))
+                self.wait(delay=int(countdown.get() * 1000))
 
-        return exitkey
+        return isexitkey
 
     def wait(self, delay=100):
         """Wait delay in ms"""
@@ -1054,15 +1163,23 @@ class GlancesCursesClient(_GlancesCurses):
     pass
 
 
-if not WINDOWS:
-    class GlancesTextbox(Textbox, object):
+class GlancesTextbox(Textbox, object):
 
-        def __init__(self, *args, **kwargs):
-            super(GlancesTextbox, self).__init__(*args, **kwargs)
+    def __init__(self, *args, **kwargs):
+        super(GlancesTextbox, self).__init__(*args, **kwargs)
 
-        def do_command(self, ch):
-            if ch == 10:  # Enter
-                return 0
-            if ch == 127:  # Back
-                return 8
-            return super(GlancesTextbox, self).do_command(ch)
+    def do_command(self, ch):
+        if ch == 10:  # Enter
+            return 0
+        if ch == 127:  # Back
+            return 8
+        return super(GlancesTextbox, self).do_command(ch)
+
+
+class GlancesTextboxYesNo(Textbox, object):
+
+    def __init__(self, *args, **kwargs):
+        super(GlancesTextboxYesNo, self).__init__(*args, **kwargs)
+
+    def do_command(self, ch):
+        return super(GlancesTextboxYesNo, self).do_command(ch)
