@@ -22,7 +22,7 @@ from __future__ import unicode_literals
 
 import operator
 
-from glances.compat import u, nativestr, n
+from glances.compat import u, nativestr, PermissionError
 from glances.plugins.glances_plugin import GlancesPlugin
 
 import psutil
@@ -103,8 +103,6 @@ class Plugin(GlancesPlugin):
                 return self.stats
 
             # Optionnal hack to allow logicals mounts points (issue #448)
-            # Ex: Had to put 'allow=zfs' in the [fs] section of the conf file
-            #     to allow zfs monitoring
             for fstype in self.get_conf_value('allow'):
                 try:
                     fs_stat += [f for f in psutil.disk_partitions(all=True) if f.fstype.find(fstype) >= 0]
@@ -114,7 +112,8 @@ class Plugin(GlancesPlugin):
             # Loop over fs
             for fs in fs_stat:
                 # Do not take hidden file system into account
-                if self.is_hide(fs.mountpoint):
+                # Also check device name (see issue #1606)
+                if self.is_hide(fs.mountpoint) or self.is_hide(fs.device):
                     continue
                 # Grab the disk usage
                 try:
@@ -163,7 +162,11 @@ class Plugin(GlancesPlugin):
                         'used': used,
                         'percent': percent,
                         'key': self.get_key()}
-                    stats.append(fs_current)
+                    # Do not take hidden file system into account
+                    if self.is_hide(fs_current['mnt_point']):
+                        continue
+                    else:
+                        stats.append(fs_current)
             else:
                 # Default behavior
                 for fs in fs_stat:
@@ -174,7 +177,11 @@ class Plugin(GlancesPlugin):
                         'used': int(fs_stat[fs]['used']) * 1024,
                         'percent': float(fs_stat[fs]['percent']),
                         'key': self.get_key()}
-                    stats.append(fs_current)
+                    # Do not take hidden file system into account
+                    if self.is_hide(fs_current['mnt_point']) or self.is_hide(fs_current['device_name']):
+                        continue
+                    else:
+                        stats.append(fs_current)
 
         # Update the stats
         self.stats = stats
@@ -190,7 +197,7 @@ class Plugin(GlancesPlugin):
         # Alert
         for i in self.stats:
             self.views[i[self.get_key()]]['used']['decoration'] = self.get_alert(
-                i['used'], maximum=i['size'], header=i['mnt_point'])
+                current=i['size'] - i['free'], maximum=i['size'], header=i['mnt_point'])
 
     def msg_curse(self, args=None, max_width=None):
         """Return the dict to display in the curse interface."""
