@@ -19,11 +19,43 @@
 
 """Virtual memory plugin."""
 
+from glances.logger import logger
 from glances.compat import iterkeys
 from glances.plugins.glances_plugin import GlancesPlugin
 
 import psutil
 
+# Fields description
+fields_description = {
+    'total': {'description': 'Total physical memory available.',
+              'unit': 'bytes'},
+    'available': {'description': 'The actual amount of available memory that can be given instantly \
+to processes that request more memory in bytes; this is calculated by summing \
+different memory values depending on the platform (e.g. free + buffers + cached on Linux) \
+and it is supposed to be used to monitor actual memory usage in a cross platform fashion.',
+                  'unit': 'bytes'},
+    'percent': {'description': 'The percentage usage calculated as (total - available) / total * 100.',
+                'unit': 'percent'},
+    'used': {'description': 'Memory used, calculated differently depending on the platform and \
+designed for informational purposes only.',
+             'unit': 'bytes'},
+    'free': {'description': 'Memory not being used at all (zeroed) that is readily available; \
+note that this doesn\'t reflect the actual memory available (use \'available\' instead).',
+             'unit': 'bytes'},
+    'active': {'description': '*(UNIX)*: memory currently in use or very recently used, and so it is in RAM.',
+               'unit': 'bytes'},
+    'inactive': {'description': '*(UNIX)*: memory that is marked as not used.',
+                 'unit': 'bytes'},
+    'buffers': {'description': '*(Linux, BSD)*: cache for things like file system metadata.',
+                'unit': 'bytes'},
+    'cached': {'description': '*(Linux, BSD)*: cache for various things.',
+               'unit': 'bytes'},
+    'wired': {'description': '*(BSD, macOS)*: memory that is marked to always stay in RAM. It is never moved to disk.',
+              'unit': 'bytes'},
+    'shared': {'description': '*(BSD)*: memory that may be simultaneously accessed by multiple processes.',
+               'unit': 'bytes'},
+}
+
 # SNMP OID
 # Total RAM in machine: .1.3.6.1.4.1.2021.4.5.0
 # Total RAM used: .1.3.6.1.4.1.2021.4.6.0
@@ -63,7 +95,8 @@ class Plugin(GlancesPlugin):
         """Init the plugin."""
         super(Plugin, self).__init__(args=args,
                                      config=config,
-                                     items_history_list=items_history_list)
+                                     items_history_list=items_history_list,
+                                     fields_description=fields_description)
 
         # We want to display the stat in the curse interface
         self.display_curse = True
@@ -82,10 +115,15 @@ class Plugin(GlancesPlugin):
 
             # Get all the memory stats (copy/paste of the psutil documentation)
             # total: total physical memory available.
-            # available: the actual amount of available memory that can be given instantly to processes that request more memory in bytes; this is calculated by summing different memory values depending on the platform (e.g. free + buffers + cached on Linux) and it is supposed to be used to monitor actual memory usage in a cross platform fashion.
+            # available: the actual amount of available memory that can be given instantly
+            # to processes that request more memory in bytes; this is calculated by summing
+            # different memory values depending on the platform (e.g. free + buffers + cached on Linux)
+            # and it is supposed to be used to monitor actual memory usage in a cross platform fashion.
             # percent: the percentage usage calculated as (total - available) / total * 100.
-            # used: memory used, calculated differently depending on the platform and designed for informational purposes only.
-            # free: memory not being used at all (zeroed) that is readily available; note that this doesn’t reflect the actual memory available (use ‘available’ instead).
+            # used: memory used, calculated differently depending on the platform and designed for informational
+            # purposes only.
+            # free: memory not being used at all (zeroed) that is readily available; note that this doesn’t
+            # reflect the actual memory available (use ‘available’ instead).
             # Platform-specific fields:
             # active: (UNIX): memory currently in use or very recently used, and so it is in RAM.
             # inactive: (UNIX): memory that is marked as not used.
@@ -161,7 +199,7 @@ class Plugin(GlancesPlugin):
 
         # Add specifics informations
         # Alert and log
-        self.views['used']['decoration'] = self.get_alert_log(self.stats['used'], maximum=self.stats['total'])
+        self.views['percent']['decoration'] = self.get_alert_log(self.stats['used'], maximum=self.stats['total'])
         # Optional
         for key in ['active', 'inactive', 'buffers', 'cached']:
             if key in self.stats:
@@ -184,7 +222,8 @@ class Plugin(GlancesPlugin):
         ret.append(self.curse_add_line(msg))
         # Percent memory usage
         msg = '{:>7.1%}'.format(self.stats['percent'] / 100)
-        ret.append(self.curse_add_line(msg))
+        ret.append(self.curse_add_line(
+            msg, self.get_views(key='percent', option='decoration')))
         # Active memory usage
         if 'active' in self.stats:
             msg = '  {:9}'.format('active:')
