@@ -23,7 +23,7 @@ import psutil
 import warnings
 
 from glances.logger import logger
-from glances.compat import iteritems
+from glances.compat import iteritems, to_fahrenheit
 from glances.timer import Counter
 from glances.plugins.sensors.glances_batpercent import Plugin as BatPercentPlugin
 from glances.plugins.sensors.glances_hddtemp import Plugin as HddTempPlugin
@@ -33,11 +33,6 @@ SENSOR_TEMP_UNIT = 'C'
 SENSOR_FAN_UNIT = 'R'
 
 
-def to_fahrenheit(celsius):
-    """Convert Celsius to Fahrenheit."""
-    return celsius * 1.8 + 32
-
-
 class Plugin(GlancesPlugin):
     """Glances sensors plugin.
 
@@ -74,6 +69,11 @@ class Plugin(GlancesPlugin):
         # We want to display the stat in the curse interface
         self.display_curse = True
 
+        # Not necessary to refresh every refresh time
+        # By default set to refresh * 2
+        if self.get_refresh() == args.time:
+            self.set_refresh(self.get_refresh() * 2)
+
     def get_key(self):
         """Return the key of the list."""
         return 'label'
@@ -132,14 +132,18 @@ class Plugin(GlancesPlugin):
 
             pass
 
-        # Set the alias for each stat
+        # Global change on stats
+        self.stats = self.get_init_value()
         for stat in stats:
+            # Do not take hide stat into account
+            if self.is_hide(stat["label"].lower()):
+                continue
+            # Set the alias for each stat
             alias = self.has_alias(stat["label"].lower())
             if alias:
                 stat["label"] = alias
-
-        # Update the stats
-        self.stats = stats
+            # Update the stats
+            self.stats.append(stat)
 
         return self.stats
 
@@ -170,10 +174,26 @@ class Plugin(GlancesPlugin):
         for i in self.stats:
             if not i['value']:
                 continue
-            if i['type'] == 'battery':
-                self.views[i[self.get_key()]]['value']['decoration'] = self.get_alert(100 - i['value'], header=i['type'])
+            # Alert processing
+            if i['type'] == 'temperature_core' and not self.is_limit('critical', stat_name=i['type']):
+                if i['critical'] is None:
+                    alert = 'DEFAULT'
+                elif i['value'] >= i['critical']:
+                    alert = 'CRITICAL'
+                elif i['warning'] is None:
+                    alert = 'DEFAULT'
+                elif i['value'] >= i['warning']:
+                    alert = 'WARNING'
+                else:
+                    alert = 'OK'
+            elif i['type'] == 'battery':
+                alert = self.get_alert(current=100 - i['value'],
+                                       header=i['type'])
             else:
-                self.views[i[self.get_key()]]['value']['decoration'] = self.get_alert(i['value'], header=i['type'])
+                alert = self.get_alert(current=i['value'],
+                                       header=i['type'])
+            # Set the alert in the view
+            self.views[i[self.get_key()]]['value']['decoration'] = alert
 
     def msg_curse(self, args=None, max_width=None):
         """Return the dict to display in the curse interface."""
@@ -257,12 +277,6 @@ class GlancesGrabSensors(object):
         else:
             self.init_fan = True
 
-        # !!! Disable Fan: High CPU consumption with psutil 5.2.0 or higher
-        # Delete the two followings lines when corrected (https://github.com/giampaolo/psutil/issues/1199)
-        # Correct and tested with PsUtil 5.6.1 (Ubuntu 18.04)
-        # self.init_fan = False
-        # logger.debug("Fan speed sensors disable (see https://github.com/giampaolo/psutil/issues/1199)")
-
         # Init the stats
         self.reset()
 
@@ -311,8 +325,12 @@ class GlancesGrabSensors(object):
                     sensors_current['label'] = chipname + ' ' + str(i)
                 else:
                     sensors_current['label'] = feature.label
-                # Fan speed and unit
-                sensors_current['value'] = int(feature.current)
+                # Sensors value, limit and unit
+                sensors_current['value'] = int(getattr(feature, 'current', 0) if getattr(feature, 'current', 0) else 0)
+                warning = getattr(feature, 'high', None)
+                sensors_current['warning'] = int(warning) if warning is not None else None
+                critical = getattr(feature, 'critical', None)
+                sensors_current['critical'] = int(critical) if critical is not None else None
                 sensors_current['unit'] = type
                 # Add sensor to the list
                 ret.append(sensors_current)
